#pragma rtGlobals=1		// Use modern global access method.

// Purpose:		create a panel to select waves for export into edf file
//				export the selected waves
//				data structure: root:oneFolder:subfolder:datawaves
//				there must be a folder root:oneFOlder:INfo which contains timings Wave (lights ON/OFF time)
//				this folder can be generated within the export process
// Input:			information for edf file via user interface				
// Output in Igor:	folder with edf variables
// Sideeffects:	if T or RH in chamber DMPS is exported the stdev will be added if waves exist

Function CreateEDFwindow()
//+++++++++++++++++++++++++++++
//	global variables to store edf info		+
//+++++++++++++++++++++++++++++
//string variables have exact same name as in edf header, textbox in edf export window have same name + Txt
//check if edf parameters already exist if not: create them
//this are the default values. they will be replaced by the current values if the export button is pressed
String savDF= GetDataFolder(1)
//create set of global variables with start values if they do not exist
IF (exists("root:edfParams:ncdf_globalName") != 1)
	NewDataFolder/O/S root:edfParams
	Make/O/T/N=(16) ncdf_globalName,ncdf_globalInfo
	ncdf_globalName[0]= "PI_NAME"
	ncdf_globalInfo[0]="Angela Buchholz"
	ncdf_globalName[1] ="EMAIL"
	ncdf_globalInfo[1]="angela.buchholz@manchester.ac.uk"
	ncdf_globalName[2] ="PHONE"
	ncdf_globalInfo[2]="+441613063928"
	ncdf_globalName[3] ="WORKGROUP"
	ncdf_globalInfo[3]="SEAS CAS"
	ncdf_globalName[4] ="INSTITUTE"
	ncdf_globalInfo[4]="University of Manchester"
	ncdf_globalName[5] ="EXPERIMENT"
	ncdf_globalInfo[5]="experiment name"
	ncdf_globalName[6] ="CAMPAIGN"
	ncdf_globalInfo[6]="AcidPruf"
	ncdf_globalName[7] ="TITLE"
	ncdf_globalInfo[7]="alpha-pinene SOA formation and transformation"
	ncdf_globalName[8] ="PLATFORM"
	ncdf_globalInfo[8]="chamber"
	ncdf_globalName[9] ="NAME_OF_PLATFORM"
	ncdf_globalInfo[9]="MASCAPITAS"
	ncdf_globalName[10]= "TYPE_OF_DATA"
	ncdf_globalInfo[10]="measurements"
	ncdf_globalName[11] ="DATA_CATEGORY"
	ncdf_globalInfo[11]="experiment"
	ncdf_globalName[12] ="STATUS_OF_FILE"
	ncdf_globalInfo[12]="preliminary"
	ncdf_globalName[13] ="VERSION"
	ncdf_globalInfo[13]="1.0"
	ncdf_globalName[14] ="DESCRIPTION"
	ncdf_globalInfo[14]="-"
	ncdf_globalName[15] ="ADDRESS"
	ncdf_globalInfo[15]="Simon Building, Oxford Road, Manchester, M13 9PL, UK"
	
	String/g ExportThisExperiment
	String/g ExportThisInstrument
	SetDataFolder "root:"
ENDIF

//++++++++++++++++++++++++++
//	create panel for edf export		+
//++++++++++++++++++++++++++
//kill exsisting panel
If (WinType("edf_export_Panel")!=0)
	KillWindow $"edf_export_Panel"
endif
NewPanel /W=(600,50,1120,700)/k=1 as "edf_export_Panel"	// /W=(left,top,right,bottom)
dowindow /c edf_export_Panel
SetDrawLayer UserBack
SetDataFolder "root:edfParams:"
// draw boxes etc...
//pos={x,y}, size={width,height}
TitleBox EDFHeaderBox ,anchor=MT, font="Arial", frame=1, fstyle=1, fsize=22,labelBack=(65535,65535,65535),size={360,55},pos={90,10},Title="    Info for edf file    "
//personal info for edf header
GroupBox personalInfo_box fColor=(0,0,0), font="Arial", frame=0, fsize=14,pos={10,55},Title="Personal Info",size={500,115}
String temp =ncdf_globalInfo[0]
SetVariable PI_nameTxt title="PI_name",bodyWidth=120, size={180,20},fsize=14, pos={25,80},value=_Str:temp,noproc
temp =ncdf_globalInfo[1]
SetVariable emailTxt title="email",bodyWidth=230, size={290,20},fsize=14, pos={210,80},value= _Str:temp, noproc
temp =ncdf_globalInfo[2]
SetVariable telephoneTxt title="telephone",bodyWidth=230, size={290,20},fsize=14, pos={210,110},value= _Str:temp,noproc
temp =ncdf_globalInfo[3]
SetVariable workgroupTxt title="workgroup",bodyWidth=120, size={180,20},fsize=14, pos={25,140},value= _Str:temp,noproc
temp =ncdf_globalInfo[4]
SetVariable InstituteTxt title="Institute",bodyWidth=230, size={290,20},fsize=14, pos={210,140},value= _Str:temp,noproc

//experiment Info for edf header
GroupBox experimentInfo_box fColor=(0,0,0), font="Arial", frame=0, fsize=14,pos={10,185},Title="Experiment Info",size={500,210}
temp =ncdf_globalInfo[5]
SetVariable experimentTxt title="experiment",bodyWidth=200, size={250,20},fsize=14, pos={40,210},value=_Str:temp,noproc
temp =ncdf_globalInfo[6]
SetVariable campaignTxt title="campaign",bodyWidth=120, size={180,20},fsize=14, pos={320,210},value= _Str:temp,noproc
temp =ncdf_globalInfo[7]
SetVariable titleTxt title="title",bodyWidth=410, size={475,20},fsize=14, pos={25,240},value=_Str:temp,noproc
temp =ncdf_globalInfo[14]
SetVariable descriptionTxt title="description",bodyWidth=410, size={475,20},fsize=14, pos={25,270},value=_Str:temp,noproc
temp =ncdf_globalInfo[8]
SetVariable platformTxt title="platform",bodyWidth=120, size={180,20},fsize=14, pos={30,300},value=_Str:temp,noproc
temp =ncdf_globalInfo[9]
SetVariable name_of_platformTxt title="platform name",bodyWidth=120, size={180,20},fsize=14, pos={320,300},value= _Str:temp,noproc
temp =ncdf_globalInfo[10]
SetVariable type_of_dataTxt title="type of data",bodyWidth=120, size={180,20},fsize=14, pos={30,330},value=_Str:temp,noproc
temp =ncdf_globalInfo[11]
SetVariable data_categoryTxt title="data category",bodyWidth=120, size={180,20},fsize=14, pos={320,330},value=_Str:temp,noproc
temp =ncdf_globalInfo[12]
SetVariable status_of_fileTxt title="status of file",bodyWidth=120, size={180,20},fsize=14, pos={30,360},value= _Str:temp,noproc
temp =ncdf_globalInfo[13]
SetVariable versionTxt title="version",bodyWidth=120, size={180,20},fsize=14, pos={320,360},value=_Str:temp,noproc

//help info
TitleBox HelpOnWaveSelect1 Frame=0, fsize=14,fstyle=4, pos={310,480},title="HELP:"
TitleBox HelpOnWaveSelect2 Frame=0, fsize=12, pos={310,500},title= "+ select experiment folder"
TitleBox HelpOnWaveSelect3 Frame=0, fsize=12, pos={310,520},title="+ select instrument folder"
TitleBox HelpOnWaveSelect4 Frame=0, fsize=12, pos={310,540},title="+ select ONE wave containing time series"
TitleBox HelpOnWaveSelect5 Frame=0, fsize=12, pos={310,560},title="+ to select multiple data waves:"
TitleBox HelpOnWaveSelect6 Frame=0, fsize=12, pos={310,580},title="   hold 'shift' when clicking on wave name"

//select the waves
GroupBox devider_line fColor=(0,0,0), font="Arial", frame=0,pos={10,410}, size={500,0}
GroupBox SelectWaves_box fColor=(0,0,0), font="Arial",frame=0, fsize=14,pos={10,415},Title="select experiment",size={500,195}
//make list of experiment folders
//set current folder to Folder

PopupMenu SelectExpFolder proc=SelectExpFolder_Popup, title="select experiment",pos={20,440},fsize=14, value=(ModifiedFolderList())
ControlInfo/w=EDF_EXport_Panel SelectExpFolder
ExportThisExperiment=S_value
//root:edfParams:ExportPath="root:"+S_value+":"
SelectExpFolder_Popup("SelectExpFolder",2,S_value)	//run the popup menu function

//Buttons
Button EDFcancel,pos={350,620},size={100,20},disable=0,fsize=14, font=arial, proc=EDF_cancel_Button,title="Cancel"	// cancel button
Button EDFdoExport,pos={10,620},size={100,20},fcolor=(65535,0,0),fstyle=1,fsize=14, disable=0, font=arial, proc=EDF_doExport_Button,title="Export"	// cancel button
SetDataFolder "root:"

END

//==============================================

//When folder is selected in dropdown menu refresh the other menus
FUNCTION SelectExpFolder_Popup (ctrlName,popNum,popStr) : PopupMenuControl	

String CtrlName,popStr
Variable popNum

ControlInfo/w=EDF_EXport_Panel SelectExpFolder	//get info from widget
SVAR ExportPath,ExportThisExperiment,ExportThisInstrument
Setdatafolder "root:edfParams"
ExportThisExperiment=S_value	//update the global export path
ExportPath="root:"+S_value+":"	//update the global export path

// refresh popup and list
// select Instrument to be exported -> will call SelectInstrumentFolder_Popup function
String/G expPath="root:"+S_value+":"
PopupMenu SelectInstrumentFolder proc=SelectInstrumentFolder_Popup,  title="select instrument",pos={290,440},fsize=14, value=(Wrapper())	//GetAllFolders(expPath)
ControlInfo/w=EDF_EXport_Panel SelectInstrumentFolder	//get info from widget

ExportThisInstrument=S_value	//update the global export path
SelectInstrumentFolder_Popup ("SelectInstrumentFolder",1,S_value)		//run popup menu function

SetDatafolder "root:"
END

//==============================================

//When instrument is selected list of waves is refreshed
Function SelectInstrumentFolder_Popup (ctrlName,popNum,popStr) : PopupMenuControl	

String CtrlName,popstr
Variable popNum	

SetDatafolder root:edfParams
	
ControlInfo/w=EDF_EXport_Panel SelectExpFolder
SVAR ExportThisExperiment, ExportThisInstrument
ExportThisExperiment=S_value
String CurrentPath = "Root:"+S_value+":"+popstr+":"
ControlInfo/w=EDF_EXport_Panel SelectInstrumentFolder	//get info from widget
ExportThisInstrument=popstr	//update the global export path

//select data waves for export
IF (CountObjects(CurrentPath,1) !=0 && StringMatch(popstr, "") !=1)	// do this only if there is an instrument folder)
	GetAllWaves2Wave(CurrentPath)
	//find a time wave
	findValue/text="time" ListOfWaves
	SetDataFolder root:
	Variable timeIdx=V_value
	If (timeIdx<0)		//120724: change from simple abort to user input
		DoAlert 1, "no time wave found in folder: \r"+ CurrentPath +"\r\rDo you want to abort?"
		IF (V_FLAG==1)
			Abort 	
		ELSE
			RETURN -1
		ENDIF
	endif
ELSE
	Make/O/T/N=1 root:edfParams:ListOfWaves="empty"	// if no waves are in the selected folder: create empty list
ENDIF

Make/D/O/N=(numpnts(root:edfParams:ListOfWaves)) root:edfParams:selectedDataWaves, root:edfParams:selectedTimeWave
Make/O/T/N=2 ListTitle0="Time Series"
Make/O/T/N=2 ListTitle1="Data Waves"
ListBox SelectDataWaveList,pos={170,470},size={135,135},listWave=root:edfParams:ListOfWaves,selWave=root:edfParams:selectedDataWaves,mode= 4, titleWave=ListTitle1
ListBox SelectTimeWaveList,pos={20,470},size={135,135},listWave=root:edfParams:ListOfWaves,selWave=root:edfParams:selectedTimeWave,mode= 2, titleWave=ListTitle0, selrow=timeIdx , proc=SelectTimeWaveListEvent

END

//==============================================

FUNCTION SelectTimeWaveListEvent(ctrlname,row,col,event) : ListBoxControl	//cell was selected in timedatawave list
String ctrlname
Variable  row,col,event

if (event == 4)
	//update selectedTImeWave
	SetDataFOlder "root:edfParams:"
	Make/O/D/N=(numpnts(SelectedDataWaves)) selectedTimeWave=0
	Listbox SelectTimeWaveList, selrow=row
	SelectedTimeWave[row]=1
	SetDataFolder "root:"
endif

END

//==============================================

FUNCTION EDF_cancel_Button(ctrlname):ButtonControl		//close window if cancel was clicked
String CtrlName
//clean up
KillWaves/Z TempWave,TempSelected, ncdf_timePrint,ncdf_columnHeader,ncdf_DataHeader,ncdf_globalPrint
SetDataFolder root:
DoWindow/k edf_export_Panel

End

//==============================================

FUNCTION EDF_doExport_Button(ctrlname):ButtonControl	//start export to edf file

String CtrlName
Variable i

//go to right data folder
SetDataFolder "root:edfParams:"
SVAR ExportThisInstrument,ExportThisExperiment, ExportPath
ControlInfo/w=EDF_EXport_Panel SelectExpFolder
ExportThisExperiment=S_value
String ExperimentFolder=S_value
ControlInfo/w=EDF_EXport_Panel SelectInstrumentFolder
ExportThisInstrument=S_value //uebernimmt nicht den neuen Wert!!!
String Instrument = S_value

String FullPath= "root:"+ExperimentFolder+":"+Instrument+":"
SetDataFolder FullPath	//go to correct folder

// prompt user for time slice to export
//give experiment start and end as stored in chamber info
String/G ExportStartStr, ExportEndStr

//create strings with clear text date time
IF (DatafolderExists("root:"+ExperimentFolder+":Info:")!=1)
	Create_Timings(ExperimentFolder)
ENDIF
SetDatafolder  "root:"+ExperimentFolder+":Info:"	//120724: if no info data folder is there: create your own timings

Wave timings		//Note: I should put the Timings used for TImeAfterLightsON calculation into each instrument folder!
Variable LightsOnSecs=timings[0]
Variable LightsOffSecs=timings[1]
SetDataFolder $Fullpath

//make String List of export Waves
Wave ListOfWaves
String/G ListOfExportWaves=""
ListOfExportWaves=MakeStringList(root:edfParams:ListOfWaves,root:edfParams:selectedTimeWave,root:edfParams:SelectedDataWaves)
//check for time after lights wave (can be first or any of the waves)
String AfterNameList=GrepList(ListOfExportWaves,"(?i)after(?i)light")	//List of waves with afterlights in name
IF (StringMatch(AfterNameList,"")!=1)
	FOR (i=0;i<itemsInList(AfterNameList);i+=1)
		IF (StringMatch(StringFromList(i,AfterNameList),"*_Sec")!=1)
			Wave CurrentTimeWave=$StringFromList(i,AfterNameList)
			String newName=StringFromList(i,AfterNameList)+"_SEC"
			KillWaves/z $NewName
			duplicate/O $StringFromList(i,AfterNameList) $NewName
			Wave TempTimeWave=$NewName
			Variable TimeInterval=CurrentTimeWave[2]-CurrenttimeWave[1]	//skip very first point as this can be wrong for some instruments
			IF (timeInterval<1)	//timesteps should be in range 1sec to 10min
				//change from hours into seconds
				TempTimeWave*=3600
				ListOfExportWaves= ReplaceString(StringFromList(i,AfterNameList),ListOfExportWaves,NewName)
				Print "ATTENTION: Time after lights on was given in hours but is exported in seconds"
			ENDIF
		ENDIF
	ENDFOR
ENDIF

String TimePath="root:"+ExperimentFolder+":"+Instrument+":"+StringFromList(0,ListOfExportWaves)
Wave TempTime=$TimePath
Variable DataStartSecs=TempTime[0]
Variable DataEndSecs=TempTime[numpnts(TempTime)-1]
String/G LightsOnStr,LightsOFFStr,DataStartStr,DataEndStr
//go back to real time for Time_AfterLightsON
IF (StringMatch(StringFromList(0,ListOfExportWaves),"*AfterLights*")==1)
	DataStartSecs+=lightsONSecs	
	DataEndSecs+=LightsONSecs
ENDIF	
LightsONStr=secs2Time(LightsONSecs,1)+" "+secs2Date(LightsONSecs,-1)
LightsOFFStr=Secs2time(LightsOffSecs,1)+" "+secs2Date(LightsOFFSecs,-1)
DataStartStr=secs2Time(DataStartSecs,1)+" "+secs2Date(DataStartSecs,-1)
DataEndStr=secs2Time(DataEndSecs,1)+" "+secs2Date(DataEndSecs,-1)
LightsONStr=RemoveListItem(2,lightsOnStr," ") //remove third item which is day of week
LightsOFFStr=RemoveListItem(2,LightsOFFStr," ")
DataStartStr=RemoveListItem(2,DataStartStr," ")
DataEndStr=RemoveListItem(2,DataEndStr," ")
LightsONStr=replaceString("/",lightsOnStr,".") //remove third item which is day of week
LightsOFFStr=replaceString("/",LightsOFFStr,".")
DataStartStr=replaceString("/",DataStartStr,".")
DataEndStr=replaceString("/",DataEndStr,".")

//create input dialog -> pressing ok in this new dialog will start real export
DoWindow/k Choose_Export_Time
NewPanel/m/w=(15,6,22,12) as "Choose_Export_Time"	//let it float on top of export panel /w=(-7,1,9,7.5)/host=edf_export_panel/ext=0
DoWindow/c Choose_Export_Time
SetDrawEnv Fname="MS Sans Serif",fstyle=1,fsize=14
DrawText 5,20,"data available: "
SetDrawEnv Fname="MS Sans Serif",fsize=14,fstyle=0,textxjust= 0,textyjust=2
DrawText 5,23, DataStartStr + " - "+DataEndStr
SetDrawEnv Fname="MS Sans Serif",fsize=14,fstyle=0,textxjust= 0,textyjust=2
DrawText 5,50, "lights ON:   "+ LightsONStr
SetDrawEnv Fname="MS Sans Serif",fsize=14,fstyle=0,textxjust= 0,textyjust=2
DrawText 5,70, "lights OFF: " + LightsOFFStr

ExportStartStr=secs2Time(LightsONSecs-600,1)+" "+secs2Date(LightsONSecs,-1) //default value: 10min before lights ON
ExportEndStr=secs2time(LightsOFFSecs+600,1)	+" "+secs2Date(LightsOFFSecs,-1)//default value: 10 min after lights OFF
ExportStartStr=RemoveListItem(2,ExportStartStr," ")
ExportEndStr=RemoveListItem(2,ExportEndStr," ")
ExportStartStr=ReplaceString("/",ExportStartStr,".")
ExportEndStr=ReplaceString("/",ExportEndStr,".")
SetVariable ExportStartTXT title="Export start",bodyWidth=120, size={180,20},fsize=14, pos={15,100},value=_Str:ExportStartStr,noproc
SetVariable ExportEndTXT title="Export start",bodyWidth=120, size={180,20},fsize=14, pos={15,130},value=_Str:ExportEndStr,noproc
 
Button FullExportTime,pos={10,160},size= {100,20},disable=0,fsize=14, font=arial,proc=EDF_ExportTime_Full_Button, title="Full"
Button LightExportTime,pos={150,160},size= {100,20},disable=0,fsize=14, font=arial,proc=EDF_ExportTime_Light_Button, title="Lights ON"
GroupBox devider_line1 fColor=(0,0,0), font="Arial", frame=0,pos={10,190}, size={240,0}
Button CancelExportTime,pos={10,200},size= {100,20},disable=0,fsize=14, font=arial,proc=EDF_ExportTime_cancel_Button, title="Cancel"
Button OKExportTime,pos={150,200},size= {100,20},disable=0,fsize=14, font=arial,proc=EDF_ExportTime_ok_Button, title="Ok"

//clean up
KillWaves/Z TempWave,TempSelected, ncdf_timePrint,ncdf_columnHeader,ncdf_DataHeader,ncdf_globalPrint
//SetDataFolder "root:"	//go back to top data folder

End

//==============================================
//set export interval to maximum
Function EDF_ExportTime_full_Button(CtrlName): Buttoncontrol

String CtrlName
String currentfolder=getdatafolder(1)		//problem if not in export datafolder
SVAR dataStartStr=$currentfolder+"dataStartStr"	//should be stored in the current datafolder
SVAR dataEndStr=$currentfolder+"dataEndStr"	//should be stored in the current datafolder

SetVariable ExportStartTXT, value=_Str: dataStartStr
SetVariable ExportEndTXT, value=_Str: dataEndStr

END

//==============================================
//set export interval to maximum
Function EDF_ExportTime_light_Button(CtrlName): Buttoncontrol

String CtrlName
String currentfolder=getdatafolder(1)		//problem if not in export datafolder
SVAR LightsONStr=$currentfolder+"LightsONStr"	//should be stored in the current datafolder
SVAR LightsOFFStr=$currentfolder+"LightsOFFStr"	//should be stored in the current datafolder

SetVariable ExportStartTXT, value=_Str: LightsONStr
SetVariable ExportEndTXT, value=_Str: LightsOFFStr

END

//==============================================
//cancel selection of export time -> return to wave selection
Function EDF_ExportTime_cancel_Button(CtrlName): Buttoncontrol

String CtrlName
SetDataFolder root:
DoWindow/k Choose_Export_Time

END

//==============================================
//real export is only started after times have been selected
Function EDF_ExportTime_ok_Button(CtrlName): Buttoncontrol

String CtrlName

//get selected waves
SetDataFolder "root:edfParams:"
SVAR ExportThisInstrument,ExportThisExperiment, ExportPath
ControlInfo/w=EDF_EXport_Panel SelectExpFolder
ExportThisExperiment=S_value
String ExperimentFolder=S_value
ControlInfo/w=EDF_EXport_Panel SelectInstrumentFolder
ExportThisInstrument=S_value //uebernimmt nicht den neuen Wert!!!
String Instrument = S_value

//print header in file
///delete old header
String FullPath= "root:"+ExperimentFolder+":"+Instrument+":"
SetDataFolder FullPath	//go to correct folder
KillWaves/Z ncdf_globalPrint

// start exporting
// get info for header
SetDataFolder "root:edfParams:"
Make/O/T/N=17 ncdf_globalPrint	//this wave is used for exporting
Wave/T ncdf_globalInfo
String printStr="!! This file was created "
printstr=printstr + date()+" " +time()
ncdf_globalPrint[0]="!! This file was created "+ date()+" " +time()
ncdf_globalPrint[1]="X_HEADER=NETCDF_GLOBAL"

//SVAR PI_name,email,telephone,workgroup,institute,experiment,campaign,title,description,platform,name_of_platform,type_of_data,data_category,status_of_file,version
ControlInfo/w=EDF_EXport_Panel PI_nameTxt
ncdf_globalInfo[0]=S_value
ncdf_globalPrint[2]="PI_NAME="+S_value
ControlInfo/w=EDF_EXport_Panel emailTxt
ncdf_globalInfo[1]=S_value
ncdf_globalPrint[3]="EMAIL="+S_value
ControlInfo/w=EDF_EXport_Panel telephoneTxt
ncdf_globalInfo[2]=S_value
ncdf_globalPrint[4]="PHONE="+S_value
ControlInfo/w=EDF_EXport_Panel workgroupTxt
ncdf_globalInfo[3]=S_value
ncdf_globalPrint[5]="WORKGROUP="+S_value
ControlInfo/w=EDF_EXport_Panel InstituteTxt
ncdf_globalInfo[4]=S_value
ncdf_globalPrint[6]="INSTITUTE="+S_value
ControlInfo/w=EDF_EXport_Panel experimentTxt
ncdf_globalInfo[5]=S_value
ncdf_globalPrint[7]="EXPERIMENT="+S_value
ControlInfo/w=EDF_EXport_Panel campaignTxt
ncdf_globalInfo[6]=S_value
ncdf_globalPrint[8]="CAMPAIGN="+S_value
ControlInfo/w=EDF_EXport_Panel titleTxt
ncdf_globalInfo[7]=S_value
ncdf_globalPrint[9]="TITLE="+S_value
ControlInfo/w=EDF_EXport_Panel descriptionTxt
ncdf_globalInfo[14]=S_value
ncdf_globalPrint[16]="DESCRIPTION="+S_value
ControlInfo/w=EDF_EXport_Panel platformTxt
ncdf_globalInfo[8]=S_value
ncdf_globalPrint[10]="PLATFORM="+S_value
ControlInfo/w=EDF_EXport_Panel name_of_platformTxt
ncdf_globalInfo[9]=S_value
ncdf_globalPrint[11]="NAME_OF_PLATFORM="+S_value
ControlInfo/w=EDF_EXport_Panel type_of_dataTxt
ncdf_globalInfo[10]=S_value
ncdf_globalPrint[12]="TYPE_OF_DATA="+S_value
ControlInfo/w=EDF_EXport_Panel data_categoryTxt
ncdf_globalInfo[11]=S_value
ncdf_globalPrint[13]="DATA_CATEGORY="+S_value
ControlInfo/w=EDF_EXport_Panel status_of_fileTxt
ncdf_globalInfo[12]=S_value
ncdf_globalPrint[14]="STATUS_OF_FILE="+S_value
ControlInfo/w=EDF_EXport_Panel versionTxt
ncdf_globalInfo[13]=S_value
ncdf_globalPrint[15]="VERSION="+S_value

MoveWave ncdf_globalPrint,$(fullPath)	
SetDataFolder FullPath	//go to correct folder

//create netcdf global info
String fileFilter="All Files:.*;"
Variable refNum
Open/D/F=fileFilter refNum
String exportFile=S_filename
If (StringMatch(exportFile,"")==1)
	abort
Endif
//print first part of header
Save/M="\r\n"/j/A=0/O ncdf_globalPrint as exportFile

//export selected waves
//get String List of Waves
SVAR ListOfExportWaves=$FullPath+"ListOfExportWaves"

//time info
Make/O/T/N=6 ncdf_TimePrint
ncdf_TimePrint[0]="X_HEADER=NETCDF_TIME "
ncdf_TimePrint[1]="SHORT_NAME(0)=time"
ncdf_TimePrint[5]="X_HEADER=NETCDF_PARAMETER"
Variable/g LightOnVar
String LightsONTime
IF (StringMatch(StringFromList(0,ListOfExportWaves),"*AfterLights*")==1)
	ncdf_TimePrint[2]="LONG_NAME(0)=time (since lights on)"
	SetDatafolder  "root:"+ExperimentFolder+":Info:"
	Wave timings
	LightOnVar=timings[0]
	SetDataFolder $Fullpath
	LightsONTime=Secs2Date(LightOnVar,-2)+" "+Secs2Time(LightOnVar,3)
	ncdf_TimePrint[3]="UNITS(0)=seconds since "+LightsONTime+" GMT"
ELSE
	ncdf_TimePrint[2]="LONG_NAME(0)=time"
	ncdf_TimePrint[3]="UNITS(0)=seconds since 1904-1-1 00:00:00 GMT"	//Igor bezieht sich auch 1.1.1904
ENDIF
Save/M="\r\n"/j/A=1 ncdf_TimePrint as exportFile

//loop through list of exported waves and create header info
Variable i,noew,STDEV_ct=0,switchSTDEV=0
noew=ItemsInList(ListOfExportWaves)
Make/O/I/n=(noew) ExportFormat_digits=3	//this will be used to store number of digits after decimal point
String StdevColumnStr1="",StdevColumnStr2=""	//this will hold column header for stdev of DMPS RH and T

Make/O/T/N=(noew+3) ncdf_ColumnHeader=""
ncdf_columnHeader[0]="X_HEADER=ENZ"
ncdf_columnHeader[1]="COLUMN 1=TIME"
ncdf_columnHeader[noew+1]="NUMBER OF COLUMNS="+num2str(noew)
ncdf_columnHeader[noew+2]="&&&&&&&&&&"

FOR (i=1;i<(noew);i+=1)
	//check the dimension of selected waves: 2D is not yet supported
	Variable dimension=DimSize($(StringFromList(i,ListOfExportWaves)), 1)
	IF (dimension>0)
		abort "exporting of 2D waves in edf format is not yet supported....aborted" 
	ENDIF
	
	String units=waveunits($(StringFromList(i,ListOfExportWaves)),0)
	If (StringMatch(units,""))	//catch empty units field
		units="-"
	ENDIF
	String descriptionStr="-",instrumentStr="-",CalibrationStr="-",ShortNameStr,longNameStr
	shortNameStr=StringFromList(i,ListOfExportWaves)
	LongNameStr=ShortNameStr
	
	//if another time wave is exported:
	IF (StringMatch(StringFromList(i,ListOfExportWaves),"*AfterLights*")==1)
		ncdf_TimePrint[2]="LONG_NAME(0)=time (since lights on)"
		SetDatafolder  "root:"+ExperimentFolder+":Info:"
		Wave timings
		LightOnVar=timings[0]
		SetDataFolder $Fullpath
		LightsONTime=Secs2Date(LightOnVar,-2)+" "+Secs2Time(LightOnVar,3)
		units="UNITS(0)=seconds since "+LightsONTime+" GMT"	//winter: GMT, Summer: BST
		ExportFormat_digits[i]=1
	ENDIF
	//special treatment for different instruments
	//GAS
	IF (StringMatch(instrument,"gas"))
		shortNameStr=removeEnding(StringFromList(i,ListOfExportWaves),"ppb")
		STRSWITCH (shortNameStr)
			CASE "NO":
				longNameStr="Nitrogen monoxide"
				calibrationStr="Gas standard"
				instrumentStr="NO-NO2-NOx analyser (42C Thermo Environment Instrument Inc, USA)"
				BREAK
			CASE "NO2":
				longNameStr="Nitrogen dioxide"
				instrumentStr="NO-NO2-NOx analyser (42C Thermo Environment Instrument Inc, USA)"
				calibrationStr="Gas standard"
				BREAK
			CASE "NOx":
				longNameStr="Nitrogen dioxide + nitrogen monoxide"
				instrumentStr="NO-NO2-NOx analyser (42C Thermo Environment Instrument Inc, USA)"
				calibrationStr="Gas standard"
				BREAK
			CASE "O3":
				longNameStr="ozone"
				instrumentStr="O3 analyser ()"
				BREAK
		ENDSWITCH
		descriptionStr=shortNameStr+" mixing ratio measured with NO-NO2-NOx analyser"
		ExportFormat_digits[i]=1

	//DMPS	
	ELSEIF(STRINGMATCH(instrument, "*DMPS*") || StringMatch(instrument,"SMPS"))	
		IF (stringMatch(StringFromList(i,ListOfExportWaves),"Total_*"))
			calibrationStr="size calibration with PSL spheres"
			IF (StringMatch(instrument,"*SMPS*")==1)
				instrumentStr="SMPS TSI 3081"
			ELSEIF  (StringMatch(instrument,"*DMPS*")==1)
				instrumentStr="DMPS"
			ENDIF

			IF (stringMatch(StringFromList(i,ListOfExportWaves),"*mass*"))
				shortNameStr="Total_mass"
				longNameStr="Total mass"
				Variable density
				String Name1g=replaceString("user",StringFromList(i,ListOfExportWaves),"1g")
				Wave temp0=$StringFromList(i,ListOfExportWaves)
				Wave temp1=$(replaceString("user",StringFromList(i,ListOfExportWaves),"1g"))
				density=temp0[0]/temp1[0]
				descriptionStr=LongNameStr+", denisty of "+num2str(density)+"g/cm (Wall loss correction NOT applied)"//g/cm
				units="g/cm"
			ELSEIF (stringMatch(StringFromList(i,ListOfExportWaves),"*surface*"))
				shortNameStr="Total_surface"
				longNameStr="Total surface"
				descriptionStr=LongNameStr+" (Wall loss correction NOT applied)"
				units="nm/cm"
			ELSEIF (stringMatch(StringFromList(i,ListOfExportWaves),"*volume*"))
				shortNameStr="Total_volume"
				longNameStr="Total volume"
				descriptionStr=LongNameStr+" (Wall loss correction NOT applied)"	
				units="nm/cm"		
			ELSEIF (stringMatch(StringFromList(i,ListOfExportWaves),"*num*"))
				shortNameStr="Total_number"
				longNameStr="Total number"
				descriptionStr=LongNameStr+" (Wall loss correction NOT applied)"
				units="#/cm"
				ExportFormat_digits[i]=1
			ENDIF
		ELSEIF (stringMatch(StringFromList(i,ListOfExportWaves),"RH_chDMPS_avg"))
			shortNameStr="RH_DMPS"
			LongNameStr="RH in DMPS sheath flow in %"
			units="%"
			descriptionStr="RH and T measured with Rotronics sensor in sheath flow of DMPS averaged over the scan time"
			instrumentStr="Rotronics Sensor"
			ExportFormat_digits[i]=1
			IF (Waveexists(RH_chDMPS_stdev))	//check if stdev is present, will be added automatically
				StdevColumnStr1="STDEV(RH_DMPS)"
				switchSTDEV=1
			ENDIF
		ELSEIF (stringMatch(StringFromList(i,ListOfExportWaves),"T_chDMPS_avg"))
			shortNameStr="T_DMPS"
			LongNameStr="T in DMPS sheath flow in C"
			units="C"
			descriptionStr="RH and T measured with Rotronics sensor in sheath flow of DMPS averaged over the scan time"
			instrumentStr="Rotronics Sensor"
			ExportFormat_digits[i]=1
			IF (Waveexists(T_chDMPS_stdev))	//check if stdev is present, will be added automatically
				StdevColumnStr2="STDEV(T_DMPS)"
				switchSTDEV=1
			ENDIF
		ENDIF
		
	//chamber T and RH		
	ELSEIF (StringMatch(instrument,"Chamber") || StringMatch(instrument,"RHT"))
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"T_*"))
			LongNameStr="temperature "+StringFromList(1,ShortNameStr,"_")
			units="C"
		ELSEIF (StringMatch(StringFromList(i,ListOfExportWaves),"RH_*"))
			LongNameStr="relative humidity "+StringFromList(1,ShortNameStr,"_") 
			units="%"
		ENDIF
			
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"*EdgeTech*"))
			instrumentStr="Edgetech dewpoint hygrometer DM-C1-DS2-MH-13 "
		ELSEIF (StringMatch(StringFromList(i,ListOfExportWaves),"*RH*"))
			instrumentStr="Sensirion SHT75"
		ELSEIF(StringMatch(StringFromList(i,ListOfExportWaves),"T_*"))
			instrumentStr="Sensirion SHT75"
		ENDIF
		descriptionStr=LongNameStr+" measured with "+instrumentstr
	
	//WCPC	
	ELSEIF(StringMatch(instrument, "WCPC"))
		//wenn wall loss daten  da sind extra case dafuer
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"conc_WCPC")==1)
			shortNameStr="total_NumberConc"
			longNameStr="Total number concentration"
			descriptionStr="total particle concenrtation (Wall loss correction NOT applied)"
			instrumentStr="WCPC TSI 3785"
			ExportFormat_digits[i]=1
		ENDIF
	
	//BCPC	
	ELSEIF(StringMatch(instrument,"BCPC"))
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"conc_WCPC")==1)
			shortNameStr="total_NumberConc"
			longNameStr="Total number concentration"
			descriptionStr="total particle concenrtation (Wall loss correction NOT applied)"
			instrumentStr="BCPC TSI 3025a"
			ExportFormat_digits[i]=1
		ENDIF
	//CCN
	ELSEIF (StringMatch(instrument,"CCN") || StringMatch(experimentfolder,"CCN") )
		instrumentStr="DMT CCN-C 100"
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"*SuperSat*")==1)
			units="%"
			ExportFormat_digits[i]=3
		ENDIF
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"*D50*")==1)
			units="nm"
			ExportFormat_digits[i]=1
		ENDIF
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"kCCND50")==1)
			descriptionStr="kappa calculated from D50 values"
			units="-"
			ExportFormat_digits[i]=4
		ENDIF
		IF (StringMatch(StringFromList(i,ListOfExportWaves),"allErrorFlag")==1)
			LongNameStr="quality of fitted AF data"
			descriptionstr="0: good data, 1: bad data, 2: completely activated, 4: nothing activated"
			ExportFormat_digits[i]=0
		ENDIF

	//others
	ELSEIF (StringMatch(instrument,"ELPI"))
		//this data does not exist yet
	ELSEIF (StringMatch(instrument,"HTDMA"))
		//this data does not exist yet
	ENDIF
	
	Make/O/T/N=8 ncdf_DataHeader	//line 7 is empty
	ncdf_DataHeader[0]="SHORT_NAME("+num2str(i)+")="+shortNameStr
	ncdf_DataHeader[1]="LONG_NAME("+num2str(i)+")="+LongNameStr
	ncdf_DataHeader[2]="DESCRIPTION("+num2str(i)+")="+descriptionStr
	
	If (stringMatch(ncdf_DataHeader[3], "dat")==1)
		units="seconds since 1904-1-1 00:00:00 GMT"
	ENDIF
	ncdf_DataHeader[3]="UNITS("+num2str(i)+")="+units
	ncdf_DataHeader[4]="MISSING_VALUE("+num2str(i)+")=-9999.9"
	ncdf_DataHeader[5]="INSTRUMENT("+num2str(i)+")="+instrumentStr
	ncdf_DataHeader[6]="CALIBRATION("+num2str(i)+")="+calibrationStr
	ncdf_columnHeader[i+1]="COLUMN "+num2str(i+1+STDEV_ct)+"="+shortNameStr	//stdev must be directly after data column -> shift everything
	Save/M="\r\n"/J/A=2 ncdf_DataHeader as exportFile	//append to file
	IF (switchSTDEV==1)
		STDEV_ct+=1
		switchSTDEV=0
	ENDIF
ENDFOR
//add stdev for RH,T of chamber DMPS
IF (!StringMatch(StdevColumnStr1,""))
	//idx of T_chDMPS_avg in list of waves
	Variable idx_RH=WhichListItem("RH_chDMPS_avg",ListOfExportWaves)
	//add to column Header
	insertPoints idx_RH+2, 1, ncdf_columnHeader
	ncdf_columnHeader[idx_RH+2]="COLUMN "+num2Str(idx_RH+2)+"="+StdevColumnStr1 
	//add to formating
	insertPoints idx_RH+1,1, ExportFormat_digits
	ExportFormat_digits[idx_RH+1]=2
	//add to export wave list
	ListOfExportWaves=AddListItem("RH_chDMPS_stdev", ListOfExportWaves,";",(idx_RH+1))
ENDIF
IF (!StringMatch(StdevColumnStr2,""))
	//idx of T_chDMPS_avg in list of waves
	Variable idx_T=WhichListItem("T_chDMPS_avg",ListOfExportWaves)
	//add to column Header
	insertPoints idx_T+2, 1, ncdf_columnHeader
	ncdf_columnHeader[idx_T+2]="COLUMN "+num2Str(idx_T+2)+"="+StdevColumnStr2
	//add to formating
	insertPoints idx_T+1,1, ExportFormat_digits
	ExportFormat_digits[idx_T+1]=2
	//add to export wave list
	ListOfExportWaves=AddListItem("T_chDMPS_stdev", ListOfExportWaves,";",(idx_T+1))
ENDIF
//recalculate noew
noew=ItemsInList(ListOfExportWaves)	//if stdev waves were added this should increase
ncdf_columnHeader[numpnts(ncdf_columnHeader)-2]="NUMBER OF COLUMNS="+num2str(noew)

//print second part with column description
Save/M="\r\n"/j/A=2 ncdf_ColumnHeader as exportFile

//-------------------------------------------------------
//get info from window
SVAR ExportStartStr = $FullPath+"ExportStartStr", ExportEndStr=$FullPath+"ExportEndStr"
ControlInfo ExportStartTXT
ExportStartStr=S_value
ControlInfo ExportEndTXT
ExportEndStr=S_value

//convert into secs
String ExportStartDate=StringFromList(1,ExportStartStr," ")	//time must be in right format
String ExportEndDate=StringFromList(1,ExportEndStr," ")	
Variable ExportStartDateSecs=Date2Secs(str2num(StringFromList(2,ExportStartDate,".")),str2num(StringFromList(1,ExportStartDate,".")),str2num(StringFromList(0,ExportStartDate,".")))
Variable ExportEndtDateSecs=Date2Secs(str2num(StringFromList(2,ExportEndDate,".")),str2num(StringFromList(1,ExportEndDate,".")),str2num(StringFromList(0,ExportEndDate,".")))

String ExportStartTime=StringFromList(0,ExportStartStr," ")	//time must be in right format
String ExportEndTime=StringFromList(0,ExportEndStr," ")	
Variable ExportStartSecs=ExportStartDateSecs+60*60*str2num(StringFromList(0,ExportStartTime,":"))+60*str2num(StringFromList(1,ExportStartTime,":"))+str2num(StringFromList(2,ExportStartTime,":"))
Variable ExportEndSecs=ExportEndtDateSecs+60*60*str2num(StringFromList(0,ExportEndTime,":"))+60*str2num(StringFromList(1,ExportEndTime,":"))+str2num(StringFromList(2,ExportEndTime,":"))

//create temp waves with only the  time slice
Duplicate/O $(StringFromList(0,ListOfExportWaves)), TimeExport
Wave TimeExport	//make wave double precision
Redimension/D TimeExport
String ExportList="TimeExport"
//find the timeslice
IF (StringMatch(StringFromList(0,ListOfExportWaves),"*AfterLights*")==1)	//convert time after lights On to real time
	TimeExport+=LightONVar
ENDIF
FindLevel/Q TimeExport,ExportStartSecs
Variable idxStart=floor(V_LevelX)	//start data point
FindLevel/Q TimeExport,ExportEndSecs
Variable idxEnd=floor(V_LevelX)	//end data point
IF (StringMatch(StringFromList(0,ListOfExportWaves),"*AfterLights*")==1)	//and back again
	TimeExport-=LightONVar
ENDIF
DeletePoints (idxEnd+1),(numpnts(TimeExport)-idxEnd), TimeExport //cut off end
DeletePoints 0,idxStart,TimeExport	//cut off front

Edit/k=3/N=tempTable as "tempTable"	//make table to set format
FOR (i=1;i<noew;i+=1)		//loop through wave list
	String NewWaveName="ExportWave"+num2str(i)
	Duplicate/O $(StringFromList(i,ListOfExportWaves)),$NewWaveName
	ExportList=ExportList+";"+NewWaveName
	DeletePoints (idxEnd+1),(numpnts($NewWaveName)-idxEnd-1), $NewWaveName	//cut off end
	DeletePoints 0,idxStart,$NewWaveName	//cut off front
	Wave TempExportWave=$NewWaveName
	TempExportWave = numtype(TempExportWave[p])==2 ? -9999.90000 : TempExportWave[p]	//replace NaNs by Missing value
	
	appendtotable TempExportWave //put into table to set format for export
	ModifyTable format($NewWaveName)=3,digits($NewWaveName)=ExportFormat_digits[i]

ENDFOR

//save the waves
Save/M="\r\n"/j/F/A=2/B ExportList as exportFile

//clean up these waves,Strings,Variables
DoWindow/K tempTable
KillWaves/Z TimeExport,ncdf_TimePrint,ncdf_globalPrint,ncdf_Columnheader,ncdf_dataheader,exportFormat_digits
FOR (i=1;i<noew;i+=1)
	NewWaveName="ExportWave"+num2str(i)
	KillWaves/Z $NewWaveName
ENDFOR
KillStrings/Z ExportList,ExportStartDate,ExportEndDate,ExportStartTime,ExportEndTime,NewWaveName,ExprotList,ListOfExportWaves,LightsONStr,LightsOFFStr,units,ExportStartStr,ExportEndStr,DataStartStr,DataEndStr
KillVariables/Z LightONVar,ExportStartDateSecs,ExportEndDateSecs,ExportStartSecs,ExportEndSecs,idxStart,idxEnd,noew,i
//close window
DoWindow/k Choose_Export_Time
SetDatafolder root:
END

//==============================================
//creates string list of Waves selected for export
Function/S MakeStringList(AllWaves,SelectedTime,SelectedData)

Wave/T AllWaves
Wave SelectedTime, SelectedData
Variable i

//check if at least one time wave and data wave are selected
if ((sum(SelectedTime))==0 || (sum(SelectedData))==0)
	abort "select at least one wave containing the time series and one additional wave containing data"
endif
//find time series wave
FindValue/V=1 SelectedTime
Variable idxTimeWave=V_value	//index in AllWaves
String SelectedList=AllWaves[idxTimeWave]

//find data waves
Make/T/O/N=(numpnts(AllWaves)) TempWave=AllWaves
Make/D/O/N=(numpnts(AllWaves)) TempSelected=SelectedData

Sort SelectedData, TempWave, TempSelected	//sort selected data waves -> selected are 1 non slected are 0
FindLevel/Q TempSelected, 0.5
DeletePoints 0,(V_levelx+0.5), TempWave	//cut off leading non slected Waves
String TempWaveName
For (i=0;i<(numpnts(TempWave));i+=1)
	TempWaveName=TempWave[i]
	SelectedList=SelectedList+";"+TempWaveName
Endfor

RETURN SelectedList
END

//==============================================
//Wrapper for Popup menu creation
Function/S Wrapper()
String Folders
ControlInfo/w=EDF_EXport_Panel SelectExpFolder
String Path="root:"+S_value
folders=GetAllFolders(Path)
RETURN folders
END

//==============================================
//modify list of folders in root: to create popup menu in edf export of chamber data viewer (120724 moved here from Chamber_Panel107 program)
Function/S ModifiedFolderList()

String ListofFolders = GetAllFolders("root:")
ListOfFolders = RemoveFromList("edfParams", ListOfFolders)	//remove edfParams folder from list
//ListofFolders=SortList( ListofFolders,";",1)	//reverse sorting order
Return ListofFolders

END

//==============================================
//prompt user for timings(if no INfo folder is present)
Function Create_Timings(ExperimentFolder)
String ExperimentFolder	

//prompt for experiment folder name (can overwrite existing data)
string expfld=ExperimentFolder
prompt expfld, "Select name for experiment folder"
doprompt/HELP="Type a name for the experiment folder in quotation marks. Should start with a letter and not contain spaces" "Enter name", expfld
if(V_flag==1)
	abort 
endif
SetDataFolder "root:"
IF (DatafolderExists(expfld)!=1)
	newdatafolder/O/S $expfld	// create experiment folder
ELSE
	SetDatafolder $expfld
ENDIF
string exp_path=getdatafolder(1)
string/g currentFld="root:"+expfld
String infoPath=currentFld+":info"
newdatafolder/O/s $infoPath

SetExportTimings()

END

//======================================
//set the timings and check for common sence
Function SetExportTimings()
IF (WaveExists(Timings)==0 & numpnts(Timings)>=4)	 //if not: put dummy values in
	Make/O/D/N=4 Timings
	SetScale d 0,0,"dat", Timings
	timings[0]=3421044000.0	//28.05.2012 10:00:00		lights ON
	timings[1]=3421072800.0	//28.05.2012 18:00:00		lights OFF
	timings[2]=3421040400.0	//28.05.2012 09:00:00		start 
	timings[3]=3421073400.0	//28.05.2012 18:10:00		end
ENDIF
Wave Timings
//input dialog for timings (that is the only thing needed for the calculations)
String LightsOnStr=secs2time(timings[0],3), LightsOffStr=secs2time(timings[1],3), LightsOnDatStr=js2String(timings[0],"dd.mm.yyyy"),LightsOffDatStr=js2String(timings[1],"dd.mm.yyyy")
String StartTime=secs2time(timings[2],3), EndTime=secs2time(timings[3],3),StartDate=js2String(timings[3],"dd.mm.yyyy"), EndDate=js2String(timings[4],"dd.mm.yyyy"),infoStr

prompt StartDate, "Enter start date:"
prompt EndDate, "Enter end date:"
prompt StartTime, "Enter start time:"
prompt EndTime, "Enter end time:"
prompt LightsOnStr, "Lights on:"
prompt LightsOnDatStr, "Lights on date:"
prompt LightsOffStr, "Lights off:"
prompt LightsOffDatStr, "Lights off date:"
prompt InfoStr, "Enter experiment information:"
doprompt "Enter times", StartDate, EndDate,StartTime, EndTime,LightsOnStr,LightsOffstr, LightsOnDatStr,LightsOffDatStr,infoStr

//put new timings into wave in DMPS folder (will be moved there with data2folder)
If (V_flag==0)		//calculate new timings if continue was chosen
	Variable Temp0,Temp1,temp2,temp3
	temp0=String2js(LightsOnDatStr+" "+LightsOnStr, "dd.mm.yyyy hh:mm:ss")
	temp1=String2js(LightsOFFDatStr+" "+LightsOFFStr, "dd.mm.yyyy hh:mm:ss")
	temp2=String2js(StartDate+" "+StartTime, "dd.mm.yyyy hh:mm:ss")
	temp3=String2js(EndDate+" "+EndTime, "dd.mm.yyyy hh:mm:ss")

	//check for common sence
	IF (temp1<=temp0)
		DoAlert 1, "lights ON time must be before lights OFF time: Try again?"
		IF (V_Flag==1)
			SetExportTimings()		//start from the top
		ELSE
			abort
		ENDIF
	ENDIF
	IF (Temp3<=temp2)
		DoAlert 1, "Start time must be before end time: Try again?"
		IF (V_Flag==1)
			SetExportTimings()		//start from the top
		ELSE
			abort
		ENDIF
	ENDIF
	//set new values if all is well
	Timings[0]=temp0
	Timings[1]=temp1
	Timings[2]=temp2
	Timings[3]=temp3
	//and create chamber Info dummy
	Make/O/T/N=10 chamber_info
	chamber_info[0]=LightsOnDatStr//lights On Str and start date
	chamber_info[1]=StartTime//start time
	chamber_info[2]=LightsOnStr//lights on time
	chamber_info[3]=LightsOffDatStr//lights off date
	chamber_info[4]=LightsOffStr//lights off time
	chamber_info[5]=EndTime//end time
	chamber_info[6]=Enddate//end date
ENDIF

END

